<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:oval-def="http://oval.mitre.org/XMLSchema/oval-definitions-5"
    xmlns:unix-def="http://oval.mitre.org/XMLSchema/oval-definitions-5#unix"
    xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
    xmlns:cdf="http://checklists.nist.gov/xccdf/1.1" xmlns:xsd="http://www.w3.org/2001/XMLSchema"
    xmlns:oval-res="http://oval.mitre.org/XMLSchema/oval-results-5"
    xmlns:oval-sc="http://oval.mitre.org/XMLSchema/oval-system-characteristics-5"
    xmlns:unix-sc="http://oval.mitre.org/XMLSchema/oval-system-characteristics-5#unix"
    xmlns:ind-def="http://oval.mitre.org/XMLSchema/oval-definitions-5#independent"
    xmlns:ind-sc="http://oval.mitre.org/XMLSchema/oval-system-characteristics-5#independent"
    exclude-result-prefixes="oval-def xsl cdf xsd oval-res oval-sc unix-sc unix-def ind-sc ind-def">
    <xsl:output method="xml" indent="yes" omit-xml-declaration="yes"/>
    
    <!-- This library is to handle the OVAL checks with the two xmlfilecontent_test tests with a state.
        
        Logic :-
        <criteria negate="true" operator="OR">
        <criterion comment="Test to verify the session authorization ownership" test_ref="oval:com.mcafee.oval:tst:416269"/>
        </criteria>
        
        Ex. OVAL ID - oval:com.mcafee.oval:def:416268, oval:com.mcafee.oval:def:416304
    -->
    
    <xsl:param name="defid" />
    <xsl:template match="/">
        <xsl:call-template name="getFindings">
            <xsl:with-param name="definitionId" select="$defid"/>
        </xsl:call-template>
    </xsl:template>
    
    <xsl:template name="getFindings">
        <xsl:param name="definitionId"/>
        <xsl:variable name="result" select="/oval-res:oval_results/oval-res:results/oval-res:system/oval-res:definitions/oval-res:definition[@definition_id=$definitionId]/@result"/>
        
        <xsl:variable name="xmlContentTest_id" select="/oval-res:oval_results/oval-def:oval_definitions/oval-def:tests/ind-def:xmlfilecontent_test[1]/@id"/>
        <xsl:variable name="result1" select="/oval-res:oval_results/oval-res:results/oval-res:system/oval-res:definitions/oval-res:definition[@definition_id=$definitionId]/descendant::oval-res:criterion[@test_ref=$xmlContentTest_id]/@result"/>
        
        <xsl:variable name="definitionXmlFileTest" select="/oval-res:oval_results/oval-def:oval_definitions/oval-def:tests/ind-def:xmlfilecontent_test[@id=$xmlContentTest_id]"/>
        <xsl:variable name="xmlfilePath" select="/oval-res:oval_results/oval-def:oval_definitions/oval-def:objects/ind-def:xmlfilecontent_object[@id=$definitionXmlFileTest/ind-def:object/@object_ref]/ind-def:path/text()" />
        <xsl:variable name="xmlfileName" select="/oval-res:oval_results/oval-def:oval_definitions/oval-def:objects/ind-def:xmlfilecontent_object[@id=$definitionXmlFileTest/ind-def:object/@object_ref]/ind-def:filename/text()" />
        <xsl:variable name="pattern" select="/oval-res:oval_results/oval-def:oval_definitions/oval-def:objects/ind-def:xmlfilecontent_object[@id=$definitionXmlFileTest/ind-def:object/@object_ref]/ind-def:xpath/text()" />
        
        <xsl:variable name="xmlfilecontentObj_ref" select="/oval-res:oval_results/oval-def:oval_definitions/oval-def:tests/ind-def:xmlfilecontent_test[@id=$xmlContentTest_id]/ind-def:object/@object_ref" />
        <xsl:variable name="xmlfilecontentObj_flag" select="/oval-res:oval_results/oval-res:results/oval-res:system/oval-sc:oval_system_characteristics/oval-sc:collected_objects/oval-sc:object[@id=$xmlfilecontentObj_ref]/@flag"/>        
        
        <xsl:variable name="title" select="/oval-res:oval_results/oval-def:oval_definitions/oval-def:definitions/oval-def:definition[ @id = $definitionId ]/oval-def:metadata/oval-def:title"/>
        
        
        <xsl:variable name="fileInfo">
            <xsl:choose>
                <xsl:when test="($xmlfilePath and xmlfileName) !=' ' ">
                    <xsl:value-of select="concat($xmlfilePath,'/', $xmlfileName)"/>
                </xsl:when>
            </xsl:choose>
        </xsl:variable>        
        
        <xsl:variable name="isViolationValue">
            <xsl:choose>
                <xsl:when test="$result = 'false' ">
                    <xsl:text>true</xsl:text>
                </xsl:when>
                <xsl:when test="$result = 'true' ">
                    <xsl:text>false</xsl:text>
                </xsl:when>
            </xsl:choose>
        </xsl:variable>
        
        <xsl:variable name="message_id">
            <!-- Check if result is true ......................................... -->                       
            <xsl:if test="$result='true'">
                <xsl:choose>
                    <xsl:when test="$xmlfilecontentObj_flag = 'does not exist'">
                        <xsl:text>com.mcafee.pa.msg.configfileDoesNotExists</xsl:text>
                    </xsl:when>                    
                    <xsl:when test="$xmlfilecontentObj_flag = 'complete' and $result = 'true'" >
                        <xsl:text>com.mcafee.pa.msg.XmlPatternMatchSCAP</xsl:text>
                    </xsl:when>
                </xsl:choose>
            </xsl:if>            
            <!-- Check if result is false .......................................-->
            <xsl:if test="$result='false'">
                 <xsl:text>com.mcafee.pa.msg.XmlPatternMatchSCAP</xsl:text>                
            </xsl:if>    
        </xsl:variable>
        
        <xsl:element name="findings" namespace="http://results.pa.mcafee.com/findings/5.2">
            <xsl:attribute name="id">
                <xsl:value-of select="$definitionId"/>
            </xsl:attribute>
            <xsl:element name="finding" namespace="http://results.pa.mcafee.com/findings/5.2">
                <xsl:attribute name="messageId">
                    <xsl:value-of select="$message_id"/>
                </xsl:attribute>
                <xsl:attribute name="isViolation">
                    <xsl:value-of select="$isViolationValue"/>
                </xsl:attribute>
                <xsl:element name="instanceValue" namespace="http://results.pa.mcafee.com/findings/5.2">
                    <xsl:attribute name="key">config_name</xsl:attribute>
                    <xsl:value-of select="$title"/>
                </xsl:element>
                <xsl:element name="instanceValue" namespace="http://results.pa.mcafee.com/findings/5.2">
                    <xsl:attribute name="key">pattern</xsl:attribute>
                    <xsl:value-of select="$pattern"/>
                </xsl:element>
                <xsl:element name="instanceValue" namespace="http://results.pa.mcafee.com/findings/5.2">
                    <xsl:attribute name="key">file_info</xsl:attribute>
                    <xsl:value-of select="$fileInfo"/>
                </xsl:element>
            </xsl:element>
        </xsl:element>
    </xsl:template>
</xsl:stylesheet>

